Module substrate_builder

Module substrate_builder 

Substrate builder: runs a tokei scan once and builds a RepoSubstrate.

Functions

build_substrate
Build a RepoSubstrate from a scan of the given repo root.