Substrate builder: runs a tokei scan once and builds a RepoSubstrate.
Functions
- build_
substrate - Build a
RepoSubstratefrom a scan of the given repo root.
Substrate builder: runs a tokei scan once and builds a RepoSubstrate.
RepoSubstrate from a scan of the given repo root.